# WatchFS

Watch and sync files to another directory.

<p align="center">
   <a href="https://python.org/" target="_blank"><img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/watchfs?logo=python&style=flat-square"></a>
   <a href="https://pypi.org/project/watchfs/" target="_blank"><img src="https://img.shields.io/pypi/v/watchfs?style=flat-square" alt="pypi"></a>
   <a href="https://pypi.org/project/watchfs/" target="_blank"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/watchfs?style=flat-square"></a>
   <a href="LICENSE"><img alt="LICENSE" src="https://img.shields.io/github/license/ShigureLab/watchfs?style=flat-square"></a>
   <br/>
   <a href="https://github.com/astral-sh/uv"><img alt="uv" src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json&style=flat-square"></a>
   <a href="https://github.com/astral-sh/ruff"><img alt="ruff" src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat-square"></a>
   <a href="https://gitmoji.dev"><img alt="Gitmoji" src="https://img.shields.io/badge/gitmoji-%20😜%20😍-FFDD67?style=flat-square"></a>
</p>

## Installation

```python
uv tool install watchfs
```

## Usage

```python
watchfs src1:dst1 src2:dst2
```
